summaryrefslogtreecommitdiffstats
path: root/kfile-plugins/torrent/kfile_torrent.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit2bc1d72869b62af05ae4feafd878203b526da8c5 (patch)
tree2676903bb600bd9646644856e354940471ad84e2 /kfile-plugins/torrent/kfile_torrent.h
parent937b2991d8e78166eea904c80ad04d34607017a4 (diff)
downloadtdenetwork-2bc1d72869b62af05ae4feafd878203b526da8c5.tar.gz
tdenetwork-2bc1d72869b62af05ae4feafd878203b526da8c5.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdenetwork@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kfile-plugins/torrent/kfile_torrent.h')
-rw-r--r--kfile-plugins/torrent/kfile_torrent.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kfile-plugins/torrent/kfile_torrent.h b/kfile-plugins/torrent/kfile_torrent.h
index 203e2b55..b7b329a7 100644
--- a/kfile-plugins/torrent/kfile_torrent.h
+++ b/kfile-plugins/torrent/kfile_torrent.h
@@ -44,11 +44,11 @@ class KTorrentPlugin : public KFilePlugin
/**
* Constructs the class, and prepares for reading info on a torrent.
*
* @param tqparent the tqparent of this object
* @param name the name of this object (not user-readable)
* @param args unused by this class
*/
- KTorrentPlugin (TQObject *tqparent, const char *name, const TQStringList &args);
+ KTorrentPlugin (TQObject *parent, const char *name, const TQStringList &args);
/**
* Destructor that closes the dictionary holding the torrent information.
@@ -44,11 +44,11 @@ class KTorrentPlugin : public KFilePlugin
* Constructs the class, and prepares for reading info on a torrent.
*
- * @param tqparent the tqparent of this object
+ * @param parent the parent of this object
* @param name the name of this object (not user-readable)
* @param args unused by this class